==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/BooleanLit__5fc.h <==
// public class polyglot.ext.jl.ast.BooleanLit_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c3a1f8342f9d3b4c polyglot_ext_jl_ast_BooleanLit__5fc
// @dep_class 84a81e50f3b403c9 polyglot_ext_jl_ast_Expr__5fc
// @dep_class 72febbfa7171c309 polyglot_ext_jl_ast_Lit__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Lit__5fc

#include "polyglot/ext/jl/ast/Lit__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_
#define _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_BooleanLit$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_PrettyPrinter$object;
struct _jc_polyglot_visit_TypeChecker$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$_init$e0eeaac9c7b5af1c(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_Position$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$constantValue$84801a2c19f3b609(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$dump$30efa1ff09c02470(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *);
extern jboolean _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$isConstant$073166fd58df46c4(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$objValue$8054c9e72b8dcd51(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$typeCheck$ae9be7fcd0a04a49(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_visit_TypeChecker$object *);
extern jboolean _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$value$5010085a42dc98e4(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$value$4aee7d90b30e8099(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$constantValue$84801a2c19f3b609;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$dump$30efa1ff09c02470;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$isConstant$073166fd58df46c4;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$objValue$8054c9e72b8dcd51;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$typeCheck$ae9be7fcd0a04a49;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$value$5010085a42dc98e4;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$value$4aee7d90b30e8099;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods {
	struct _jc_java_lang_Object$object	*(*constantValue$84801a2c19f3b609)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
	void	(*dump$30efa1ff09c02470)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *);
	jboolean	(*isConstant$073166fd58df46c4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
	struct _jc_java_lang_Object$object	*(*objValue$8054c9e72b8dcd51)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
	struct _jc_object	*(*typeCheck$ae9be7fcd0a04a49)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_visit_TypeChecker$object *);
	jboolean	(*value$5010085a42dc98e4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *);
	struct _jc_object	*(*value$4aee7d90b30e8099)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, jboolean);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
	_jc_polyglot_ext_jl_ast_Expr__5fc$vmethods	polyglot_ext_jl_ast_Expr__5fc;
	_jc_polyglot_ext_jl_ast_Lit__5fc$vmethods	polyglot_ext_jl_ast_Lit__5fc;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods	polyglot_ext_jl_ast_BooleanLit__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs {
    _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs	polyglot_ext_jl_ast_BooleanLit__5fc;
    _jc_polyglot_ext_jl_ast_Lit__5fc$sub_refs	polyglot_ext_jl_ast_Lit__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_refs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs {
	jboolean	value;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_nonrefs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Lit__5fc$sub_nonrefs	polyglot_ext_jl_ast_Lit__5fc;
    _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs	polyglot_ext_jl_ast_BooleanLit__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object {
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype _jc_polyglot_ext_jl_ast_BooleanLit__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_BooleanLit__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_BooleanLit__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/BooleanLit__5fc.h <==
// public class polyglot.ext.jl.ast.BooleanLit_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c3a1f8342f9d3b4c polyglot_ext_jl_ast_BooleanLit__5fc
// @dep_class 84a81e50f3b403c9 polyglot_ext_jl_ast_Expr__5fc
// @dep_class 72febbfa7171c309 polyglot_ext_jl_ast_Lit__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Lit__5fc

#include "polyglot/ext/jl/ast/Lit__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_
#define _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_BooleanLit$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_PrettyPrinter$object;
struct _jc_polyglot_visit_TypeChecker$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$_init$e0eeaac9c7b5af1c(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_Position$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$constantValue$84801a2c19f3b609(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$dump$30efa1ff09c02470(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$isConstant$073166fd58df46c4(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$objValue$8054c9e72b8dcd51(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$typeCheck$ae9be7fcd0a04a49(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_visit_TypeChecker$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$value$5010085a42dc98e4(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_BooleanLit__5fc$method$value$4aee7d90b30e8099(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$constantValue$84801a2c19f3b609;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$dump$30efa1ff09c02470;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$isConstant$073166fd58df46c4;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$objValue$8054c9e72b8dcd51;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$typeCheck$ae9be7fcd0a04a49;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$value$5010085a42dc98e4;
extern _jc_method _jc_polyglot_ext_jl_ast_BooleanLit__5fc$method_info$value$4aee7d90b30e8099;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods {
	struct _jc_java_lang_Object$object	*(*constantValue$84801a2c19f3b609)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
	void	(*dump$30efa1ff09c02470)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *) _JC_JCNI_ATTR;
	jboolean	(*isConstant$073166fd58df46c4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*objValue$8054c9e72b8dcd51)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*typeCheck$ae9be7fcd0a04a49)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, struct _jc_polyglot_visit_TypeChecker$object *) _JC_JCNI_ATTR;
	jboolean	(*value$5010085a42dc98e4)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*value$4aee7d90b30e8099)(_jc_env *, struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
	_jc_polyglot_ext_jl_ast_Expr__5fc$vmethods	polyglot_ext_jl_ast_Expr__5fc;
	_jc_polyglot_ext_jl_ast_Lit__5fc$vmethods	polyglot_ext_jl_ast_Lit__5fc;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vmethods	polyglot_ext_jl_ast_BooleanLit__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs {
    _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_refs	polyglot_ext_jl_ast_BooleanLit__5fc;
    _jc_polyglot_ext_jl_ast_Lit__5fc$sub_refs	polyglot_ext_jl_ast_Lit__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_refs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs {
	jboolean	value;
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_nonrefs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Lit__5fc$sub_nonrefs	polyglot_ext_jl_ast_Lit__5fc;
    _jc_polyglot_ext_jl_ast_BooleanLit__5fc$sub_nonrefs	polyglot_ext_jl_ast_BooleanLit__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_BooleanLit__5fc$object {
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_BooleanLit__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_BooleanLit__5fc$vtype _jc_polyglot_ext_jl_ast_BooleanLit__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_BooleanLit__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_BooleanLit__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_BooleanLit__5fc_H_ */
